@@ -19,7 +19,7 @@
 %             MagickCore Self-adjusting Binary Search Tree Methods            %
 %                                                                             %
 %                              Software Design                                %
-%                                John Cristy                                  %
+%                                   Cristy                                    %
 %                               December 2002                                 %
 %                                                                             %
 %                                                                             %
