@@ -13,7 +13,7 @@
 %                        Digitally composite two images.                      %
 %                                                                             %
 %                              Software Design                                %
-%                                John Cristy                                  %
+%                                   Cristy                                    %
 %                               January 1993                                  %
 %                                                                             %
 %                                                                             %
